Module embedded

Module embedded 

Embedded workflow and overlay files.

These files are compiled into the binary so they’re always available, even when the install directory doesn’t exist (e.g., new projects).

Modules

overlays
Embedded overlay YAML files.
workflows
Embedded workflow YAML files.