pub struct AppConfig {
pub states: Arc<StatesConfig>,
pub phases: Arc<PhasesConfig>,
pub deps: Arc<DependenciesConfig>,
pub auto_advance: Arc<AutoAdvanceConfig>,
pub attachments: Arc<AttachmentsConfig>,
pub tags: Arc<TagsConfig>,
pub ids: Arc<IdsConfig>,
pub workflows: Arc<WorkflowsConfig>,
pub feedback: Arc<FeedbackConfig>,
}Expand description
Consolidated application configuration.
Bundles all individual config types behind Arc so that they can be shared
cheaply across tool handlers, resource handlers, and option structs.
Instead of passing 8+ individual Arc<XxxConfig> parameters, callers pass
a single &AppConfig.
Fields
states: Arc<StatesConfig>phases: Arc<PhasesConfig>deps: Arc<DependenciesConfig>auto_advance: Arc<AutoAdvanceConfig>attachments: Arc<AttachmentsConfig>ids: Arc<IdsConfig>workflows: Arc<WorkflowsConfig>feedback: Arc<FeedbackConfig>Implementations
Sourceimpl AppConfig
impl AppConfig
Sourcepub fn new(
states: Arc<StatesConfig>,
phases: Arc<PhasesConfig>,
deps: Arc<DependenciesConfig>,
auto_advance: Arc<AutoAdvanceConfig>,
attachments: Arc<AttachmentsConfig>,
tags: Arc<TagsConfig>,
ids: Arc<IdsConfig>,
workflows: Arc<WorkflowsConfig>,
feedback: Arc<FeedbackConfig>,
) -> Self
pub fn new( states: Arc<StatesConfig>, phases: Arc<PhasesConfig>, deps: Arc<DependenciesConfig>, auto_advance: Arc<AutoAdvanceConfig>, attachments: Arc<AttachmentsConfig>, tags: Arc<TagsConfig>, ids: Arc<IdsConfig>, workflows: Arc<WorkflowsConfig>, feedback: Arc<FeedbackConfig>, ) -> Self
Create a new AppConfig from individually wrapped configs.