pub struct AttachmentsConfig {
pub unknown_key: UnknownKeyBehavior,
pub definitions: HashMap<String, AttachmentKeyDefinition>,
}Expand description
Attachments configuration with preconfigured key definitions.
Fields
unknown_key: UnknownKeyBehaviorBehavior for unknown attachment keys (allow, warn, reject).
definitions: HashMap<String, AttachmentKeyDefinition>Preconfigured attachment key definitions.
Implementations
Sourceimpl AttachmentsConfig
impl AttachmentsConfig
Sourcepub fn default_definitions() -> HashMap<String, AttachmentKeyDefinition>
pub fn default_definitions() -> HashMap<String, AttachmentKeyDefinition>
Default attachment key definitions.
Sourcepub fn get_definition(&self, key: &str) -> Option<&AttachmentKeyDefinition>
pub fn get_definition(&self, key: &str) -> Option<&AttachmentKeyDefinition>
Get the definition for a key, if it exists.
Sourcepub fn is_known_key(&self, key: &str) -> bool
pub fn is_known_key(&self, key: &str) -> bool
Check if a key is a known/configured key.
Sourcepub fn get_mime_default(&self, key: &str) -> &str
pub fn get_mime_default(&self, key: &str) -> &str
Get the default MIME type for a key, or fallback to text/plain.
Sourcepub fn get_mode_default(&self, key: &str) -> &str
pub fn get_mode_default(&self, key: &str) -> &str
Get the default mode for a key, or fallback to “append”.