pub struct GateDefinition {
pub gate_type: String,
pub enforcement: GateEnforcement,
pub description: String,
}Expand description
Definition of a gate (checklist item) for status or phase exits.
Gates are checked when transitioning out of a status or phase. A gate is satisfied when the task has an attachment with a matching type (e.g., “gate/tests”, “gate/commit”).
Fields
gate_type: StringAttachment type that satisfies this gate (e.g., “gate/tests”, “gate/commit”).
enforcement: GateEnforcementEnforcement level for this gate.
description: StringHuman-readable description of what this gate requires.