PhasesConfig

Struct PhasesConfig 

pub struct PhasesConfig {
    pub unknown_phase: UnknownKeyBehavior,
    pub definitions: HashSet<String>,
}
Phase configuration for categorizing type of work.

Fields

unknown_phase: UnknownKeyBehavior

Behavior for unknown phase values (allow, warn, reject).

definitions: HashSet<String>

Known phase definitions.

Implementations

Source

impl PhasesConfig

pub fn is_known_phase(&self, phase: &str) -> bool

Check if a phase is a known/defined phase.

pub fn phase_names(&self) -> Vec<&str>

Get all defined phase names.

pub fn check_phase(&self, phase: &str) -> Result<Option<String>>

Check a phase and return a warning message if unknown (based on unknown_phase behavior). Returns None if the phase is known or if behavior is Allow. Returns Some(warning) if behavior is Warn. Returns Err if behavior is Reject.