ServerConfig

Struct ServerConfig 

pub struct ServerConfig {
    pub db_path: PathBuf,
    pub media_dir: PathBuf,
    pub claim_limit: i32,
    pub stale_timeout_seconds: i64,
    pub default_format: OutputFormat,
    pub skills_dir: PathBuf,
    pub log_dir: PathBuf,
    pub ui: UiConfig,
    pub default_workflow: Option<String>,
}
Server-specific configuration.

Fields

db_path: PathBuf

Path to the SQLite database file.

media_dir: PathBuf

Path to the media directory for file attachments.

claim_limit: i32

Maximum claims per agent.

stale_timeout_seconds: i64

Timeout for stale claims in seconds.

default_format: OutputFormat

Default output format for query results (json or markdown).

skills_dir: PathBuf

Path to the skills directory for skill overrides.

log_dir: PathBuf

Path to the log directory.

ui: UiConfig

UI configuration for the web dashboard.

default_workflow: Option<String>

Default workflow name (e.g., “swarm” to use workflow-swarm.yaml). If set, this workflow is used as the default for workers that don’t specify one. The named workflow is also cached under both its name and “default”.