pub struct RoleDefinition {
pub description: Option<String>,
pub tags: Vec<String>,
pub max_claims: Option<u32>,
pub can_assign: Option<bool>,
pub can_create_subtasks: Option<bool>,
}Expand description
Definition of a role in a workflow (e.g., “lead”, “worker”).
Fields
description: Option<String>Human-readable description of this role.
Tags that identify agents in this role.
max_claims: Option<u32>Maximum number of tasks this role can claim simultaneously.
can_assign: Option<bool>Whether this role can assign tasks to other agents.
can_create_subtasks: Option<bool>Whether this role can create subtasks.