Module logging

Module logging 

Unified MCP-compatible logging system.

This module provides a unified logger that outputs to multiple backends:

  • CLI/stderr/file via tracing
  • MCP client via notify_logging_message

Uses MCP LoggingLevel as the canonical level type.

Structs

LogLevelFilter
Atomic level filter that can be adjusted via logging/setLevel.
Logger
Unified logger that outputs to multiple backends.

Functions

logging_level_to_tracing
Convert MCP LoggingLevel to tracing Level.