pub struct LogLevelFilter(/* private fields */);Expand description
Atomic level filter that can be adjusted via logging/setLevel.
The level is stored as a u8 corresponding to LoggingLevel variants: 0=Debug, 1=Info, 2=Notice, 3=Warning, 4=Error, 5=Critical, 6=Alert, 7=Emergency
Implementations
Sourceimpl LogLevelFilter
impl LogLevelFilter
Sourcepub fn new(level: LoggingLevel) -> Self
pub fn new(level: LoggingLevel) -> Self
Create a new filter with the given minimum level.
Sourcepub fn get(&self) -> LoggingLevel
pub fn get(&self) -> LoggingLevel
Get the current minimum level.
Sourcepub fn set(&self, level: LoggingLevel)
pub fn set(&self, level: LoggingLevel)
Set the minimum level.
Sourcepub fn should_log(&self, level: LoggingLevel) -> bool
pub fn should_log(&self, level: LoggingLevel) -> bool
Check if a message at the given level should be logged.