Module claiming

Module claiming 

Task claiming tools.

The claim tool is a convenience wrapper around update that transitions a task to the first timed state. For releasing tasks, use update with a non-timed state (ownership clears automatically).

Functions

claim
get_tools