Read-only SQL query tool.
Provides a query tool for executing read-only SQL queries against the database.
This tool is intended for advanced users and debugging purposes.
SECURITY: This tool requires user permission before execution and only allows SELECT statements. INSERT, UPDATE, DELETE, DROP, and other modifying statements are rejected.
Enums
- Query
Format - Output format for query results.