pub struct TaskSequenceEvent {
pub id: i64,
pub task_id: String,
pub worker_id: Option<String>,
pub status: Option<String>,
pub phase: Option<String>,
pub reason: Option<String>,
pub timestamp: i64,
pub end_timestamp: Option<i64>,
pub concurrency: Option<i32>,
}Expand description
A unified task sequence event for tracking status and phase changes.
Fields
id: i64task_id: Stringworker_id: Option<String>status: Option<String>Status value (None if phase-only change)
phase: Option<String>Phase value (None if status-only change)
reason: Option<String>timestamp: i64end_timestamp: Option<i64>concurrency: Option<i32>How many timed tasks the same worker had open simultaneously. Used to normalize time_actual_ms for parallel work.