MCP tool implementations.
Re-exports
pub use context::ToolContext;
Modules
- agents
- Worker connection and management tools.
- attachments
- Attachment management tools.
- claiming
- Task claiming tools.
- context
- Per-request context passed to tool functions.
- deps
- Dependency management tools.
- files
- File coordination tools (advisory marks for file coordination).
- gates
- Gate checking tools.
- query
- Read-only SQL query tool.
- schema
- Schema introspection tool for exposing database structure.
- search
- Full-text search tool.
- skills
- Skill management tools - list and get skills.
- tasks
- Task CRUD tools.
- tracking
- Live status and tracking tools.
Structs
- Tool
Handler - Tool handler that processes MCP tool calls.
Functions
- get_
bool - Helper to get a bool from arguments.
- get_f64
- Helper to get an f64 from arguments.
- get_i32
- Helper to get an i32 from arguments.
- get_i64
- Helper to get an i64 from arguments.
- get_
string - Helper to get a string from arguments.
- get_
string_ array - Helper to get a string array from arguments.
- get_
string_ or_ array - Helper to get either a single string or array of strings from arguments.
Normalizes to a Vec
. - make_
tool - Helper to create a tool definition.
- make_
tool_ with_ prompts - Helper to create a tool definition with prompt overrides. Looks up the tool description in prompts, falls back to default_description.